# -*- coding: utf-8 -*-

from . import partner
from . import account
from . import account_reconcile_model
from . import account_payment
from . import account_payment_term
from . import account_bank_statement
from . import account_move
from . import account_payment_term
from . import account_bank_statement
from . import chart_template
from . import account_analytic_line
from . import account_journal_dashboard
from . import product
from . import account_fiscal_year
from . import company
from . import res_config_settings
from . import account_cash_rounding
from . import reconciliation_widget
from . import account_incoterms
from . import digest
from . import res_users
from . import ir_actions_report
